@@ -138,10 +138,10 @@ def create_argparse():
     # )
 
     # Uncomment to allow --debug-server (for use with VS Code pydebug)
+    # Activate the debug server to listen on specified port, wait for a client connect.
     parser.add_argument(
         "--debug-server",
-        help=argparse.SUPPRESS,  # "Activate the debug server to listen
-                                 # on specified port, wait for a client connect."
+        help=argparse.SUPPRESS,
         type=int,
         required=False,
     )
