@@ -33,6 +33,7 @@ from atbu.mp_pipeline.mp_pipeline import (
     MultiprocessingPipeline,
     SubprocessPipelineStage,
 )
+from atbu.mp_pipeline.mp_helper import wait_futures_to_regulate
 from atbu.common.exception import (
     CompareBytesMistmatchError,
     InvalidStateError,
@@ -353,6 +354,10 @@ class Verify:
                     local_compare_root_location=self.local_compare_root_location,
                     temp_dir=self._temp_dir,
                 )
+                wait_futures_to_regulate(
+                    fs=pending_verifications,
+                    max_allowed_pending=Verify.MAX_SIMULTANEOUS_FILES
+                )
                 future = self._subprocess_pipeline.submit(
                     work_item=BackupPipelineWorkItem(
                         operation_name=BACKUP_OPERATION_NAME_VERIFY,
